Package: KernelICA
Type: Package
Title: Kernel Independent Component Analysis
Version: 2.0.0
Authors@R: 
  c(person(
      given = "Christoph L.",
      family = "Koesner",
      role = "aut",
      email = "christoph@koesner.at",
      comment = c(ORCID = "0000-0002-2061-8022")),
    person(
      given = "Juho",
      family = "Eagling", 
      email = "juho.eagling@gmail.com",
      role = "aut",
      comment = c(ORCID = "0000-0001-8333-5057")),
    person(
      given = "Klaus",
      family = "Nordhausen",
      role = c("aut", "cre"),
      email = "klausnordhausenR@gmail.com",
      comment = c(ORCID = "0000-0002-3758-8501")))
Maintainer: Klaus Nordhausen <klausnordhausenR@gmail.com>
Description: 
  The kernel independent component analysis (kernel ICA) method introduced by Bach and Jordan (2002) <doi:10.1162/153244303768966085>. A separate function for the incomplete Cholesky decomposition used in kernel ICA is also provided.
License: GPL (>= 2)
Imports: methods, ManifoldOptim, JADE, ICtest
Depends: Rcpp, R (>= 4.2.0)
LinkingTo: Rcpp, RcppArmadillo, ManifoldOptim, RcppEigen
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-08-03 07:34:26 UTC; klaus
Author: Christoph L. Koesner [aut] (ORCID:
    <https://orcid.org/0000-0002-2061-8022>),
  Juho Eagling [aut] (ORCID: <https://orcid.org/0000-0001-8333-5057>),
  Klaus Nordhausen [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3758-8501>)
Repository: CRAN
Date/Publication: 2026-08-04 08:50:12 UTC
