# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

incompleteCholeskyGauss <- function(v, eps, sigma) {
    .Call('_KernelICA_incompleteCholeskyGauss', PACKAGE = 'KernelICA', v, eps, sigma)
}

incompleteCholeskyHermite <- function(v, eps, sigma, d) {
    .Call('_KernelICA_incompleteCholeskyHermite', PACKAGE = 'KernelICA', v, eps, sigma, d)
}

kernelMatrixGauss <- function(x, y, sigma) {
    .Call('_KernelICA_kernelMatrixGauss', PACKAGE = 'KernelICA', x, y, sigma)
}

kernelMatrixHermite <- function(x, y, sigma, d) {
    .Call('_KernelICA_kernelMatrixHermite', PACKAGE = 'KernelICA', x, y, sigma, d)
}

