% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/package.R
\docType{package}
\name{KernelICA-package}
\alias{KernelICA}
\alias{KernelICA-package}
\title{KernelICA-package}
\description{
The kernel independent component analysis (kernel ICA) method introduced by Bach and Jordan in 2002 (see references).
A separate function for the incomplete Cholesky decomposition used in kernel ICA is also provided.
}
\references{
Francis R. Bach, Michael I. Jordan\cr
\emph{Kernel independent component analysis}\cr
Journal of Machine Learning Research 2002\cr
\doi{10.1162/153244303768966085}

Francis R. Bach, Michael I. Jordan\cr
\emph{Predictive low-rank decomposition for kernel methods.}\cr
Proceedings of the Twenty-second International Conference on Machine Learning (ICML) 2005\cr
\doi{10.1145/1102351.1102356}.

Sean Martin, Andrew M. Raim, Wen Huang, Kofi P. Adragni\cr
\emph{ManifoldOptim: An R Interface to the ROPTLIB Library for Riemannian Manifold Optimization}\cr
Journal of Statistical Software 2020\cr
\doi{10.18637/jss.v093.i01}
}
\author{
\strong{Maintainer}: Klaus Nordhausen \email{klausnordhausenR@gmail.com} (\href{https://orcid.org/0000-0002-3758-8501}{ORCID})

Authors:
\itemize{
  \item Klaus Nordhausen \email{klausnordhausenR@gmail.com} (\href{https://orcid.org/0000-0002-3758-8501}{ORCID})
  \item Christoph L. Koesner \email{christoph@koesner.at} (\href{https://orcid.org/0000-0002-2061-8022}{ORCID})
  \item Juho Eagling \email{juho.eagling@gmail.com} (\href{https://orcid.org/0000-0001-8333-5057}{ORCID})
}

}
